Module error

Module error 

The crate-wide error type.

Every fallible operation in tangible returns a Result<T, Error>. The variants below describe each class of failure that callers may need to discriminate when handling errors at the boundary of their application.

Structs

FileOpsError
A filesystem-level error produced by a FileOps implementation.

Enums

Error
Errors produced by the tangible library.